@@ -4,14 +4,14 @@
 
 __author__ = 'MIT Data To AI Lab'
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.5.2'
+__version__ = '0.6.0'
 
 from ctgan.demo import load_demo
-from ctgan.synthesizers.ctgan import CTGANSynthesizer
-from ctgan.synthesizers.tvae import TVAESynthesizer
+from ctgan.synthesizers.ctgan import CTGAN
+from ctgan.synthesizers.tvae import TVAE
 
 __all__ = (
-    'CTGANSynthesizer',
-    'TVAESynthesizer',
+    'CTGAN',
+    'TVAE',
     'load_demo'
 )
